==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/el/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => 'Κατάσταση <strong>προγρ/σμένης εργασίας</strong>',
    '<strong>Queue</strong> Status' => 'Κατάσταση <strong>αναμονής σειράς</strong>',
    'About HumHub' => 'Σχετικά με το HumHub',
    'Background Jobs' => 'Εργασίες υπόβαθρου',
    'Base URL' => 'Βασική URL',
    'Checking HumHub software prerequisites.' => 'Έλεγχος προϋποθέσεων λογισμικού HumHub.',
    'Database' => 'Βάση δεδομένων',
    'Database migration results:' => 'Αποτελέσματα μετάβασης βάσης δεδομένων:',
    'Delayed' => 'Καθυστέρηση',
    'Displaying {count} entries per page.' => 'Εμφάνιση {count} καταχωρήσεων ανά σελίδα.',
    'Done' => 'Ολοκληρώθηκε',
    'Driver' => 'Οδηγός',
    'Error' => 'Σφάλμα',
    'Flush entries' => 'Ξέπλυμα καταχωρήσεων',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'Το HumHub βρίσκεται αυτήν τη στιγμή σε λειτουργία εντοπισμού σφαλμάτων. Απενεργοποιήστε το αν τρέχετε σε παραγωγή!',
    'Info' => 'Πληροφορίες',
    'Last run (daily):' => 'Τελευταία εκτέλεση (ημερήσια):',
    'Last run (hourly):' => 'Τελευταία εκτέλεση (ωριαία):',
    'Licences' => 'Άδειες',
    'Logging' => 'Σύνδεση',
    'Never' => 'Ποτέ',
    'Other' => 'Άλλο',
    'Permissions' => 'Δικαιώματα',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Ανατρέξτε στην τεκμηρίωση για τη ρύθμιση των προγρ/σμένων εργασιών και εργασιών αναμονής.',
    'Prerequisites' => 'Προϋποθέσεις',
    'Queue successfully cleared.' => 'Οι εργασιες αναμονής καθαρίστηκαν με επιτυχία.',
    'Re-Run tests' => 'Επαναλάβετε τις δοκιμές',
    'Reserved' => 'Κατοχυρωμένα',
    'Search index rebuild in progress.' => 'Αναδημιουργία ευρετηρίου αναζήτησης σε εξέλιξη.',
    'Search term...' => 'Όρος αναζήτησης...',
    'See installation manual for more details.' => 'Δείτε το εγχειρίδιο εγκατάστασης για περισσότερες λεπτομέρειες.',
    'Select category..' => 'Επιλέξτε Κατηγορία..',
    'Select day' => 'Επιλέξτε ημέρα',
    'Select level...' => 'Επιλέξτε Επίπεδο...',
    'Settings' => 'Ρυθμίσεις',
    'The current main HumHub database name is ' => 'Το τρέχον κύριο όνομα βάσης δεδομένων του HumHub είναι',
    'There is a new update available! (Latest version: %version%)' => 'Υπάρχει μια νέα ενημέρωση διαθέσιμη! (Τελευταία έκδοση: %version%)',
    'This HumHub installation is up to date!' => 'Αυτή η εγκατάσταση HumHub είναι ενημερωμένη!',
    'Total {count} entries found.' => 'Βρέθηκαν σύνολο {count} καταχωρίσεις.',
    'Trace' => 'Ίχνος',
    'Waiting' => 'Αναμονή',
    'Warning' => 'Προειδοποίηση',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Dynamic Config' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/el/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => 'Κατάσταση <strong>προγρ/σμένης εργασίας</strong>',
    '<strong>Queue</strong> Status' => 'Κατάσταση <strong>αναμονής σειράς</strong>',
    'About HumHub' => 'Σχετικά με το HumHub',
    'Background Jobs' => 'Εργασίες υπόβαθρου',
    'Base URL' => 'Βασική URL',
    'Checking HumHub software prerequisites.' => 'Έλεγχος προϋποθέσεων λογισμικού HumHub.',
    'Database' => 'Βάση δεδομένων',
    'Database migration results:' => 'Αποτελέσματα μετάβασης βάσης δεδομένων:',
    'Delayed' => 'Καθυστέρηση',
    'Displaying {count} entries per page.' => 'Εμφάνιση {count} καταχωρήσεων ανά σελίδα.',
    'Done' => 'Ολοκληρώθηκε',
    'Driver' => 'Οδηγός',
    'Error' => 'Σφάλμα',
    'Flush entries' => 'Ξέπλυμα καταχωρήσεων',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'Το HumHub βρίσκεται αυτήν τη στιγμή σε λειτουργία εντοπισμού σφαλμάτων. Απενεργοποιήστε το αν τρέχετε σε παραγωγή!',
    'Info' => 'Πληροφορίες',
    'Last run (daily):' => 'Τελευταία εκτέλεση (ημερήσια):',
    'Last run (hourly):' => 'Τελευταία εκτέλεση (ωριαία):',
    'Licences' => 'Άδειες',
    'Logging' => 'Σύνδεση',
    'Never' => 'Ποτέ',
    'Other' => 'Άλλο',
    'Permissions' => 'Δικαιώματα',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Ανατρέξτε στην τεκμηρίωση για τη ρύθμιση των προγρ/σμένων εργασιών και εργασιών αναμονής.',
    'Prerequisites' => 'Προϋποθέσεις',
    'Queue successfully cleared.' => 'Οι εργασιες αναμονής καθαρίστηκαν με επιτυχία.',
    'Re-Run tests' => 'Επαναλάβετε τις δοκιμές',
    'Reserved' => 'Κατοχυρωμένα',
    'Search index rebuild in progress.' => 'Αναδημιουργία ευρετηρίου αναζήτησης σε εξέλιξη.',
    'Search term...' => 'Όρος αναζήτησης...',
    'See installation manual for more details.' => 'Δείτε το εγχειρίδιο εγκατάστασης για περισσότερες λεπτομέρειες.',
    'Select category..' => 'Επιλέξτε Κατηγορία..',
    'Select day' => 'Επιλέξτε ημέρα',
    'Select level...' => 'Επιλέξτε Επίπεδο...',
    'Settings' => 'Ρυθμίσεις',
    'The current main HumHub database name is ' => 'Το τρέχον κύριο όνομα βάσης δεδομένων του HumHub είναι',
    'There is a new update available! (Latest version: %version%)' => 'Υπάρχει μια νέα ενημέρωση διαθέσιμη! (Τελευταία έκδοση: %version%)',
    'This HumHub installation is up to date!' => 'Αυτή η εγκατάσταση HumHub είναι ενημερωμένη!',
    'Total {count} entries found.' => 'Βρέθηκαν σύνολο {count} καταχωρίσεις.',
    'Trace' => 'Ίχνος',
    'Waiting' => 'Αναμονή',
    'Warning' => 'Προειδοποίηση',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Enable <a href="{url}">Link Redirection Service</a>' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for Mercure push live driver' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Uploads - File' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
